@@ -74,7 +74,7 @@ module Ronn
       @reader = block ||
                 lambda do |f|
                   if ['-', nil].include?(f)
-                    STDIN.read
+                    $stdin.read
                   else
                     File.read(f, encoding: @encoding)
                   end
@@ -211,7 +211,9 @@ module Ronn
     # tuple of the form: [name, section, description], where missing information
     # is represented by nil and any element may be missing.
     def sniff
-      html = Kramdown::Document.new(data[0, 512], auto_ids: false, smart_quotes: ['apos', 'apos', 'quot', 'quot'], typographic_symbols: { hellip: '...', ndash: '--', mdash: '--' }).to_html
+      html = Kramdown::Document.new(data[0, 512], auto_ids: false,
+        smart_quotes: ['apos', 'apos', 'quot', 'quot'],
+        typographic_symbols: { hellip: '...', ndash: '--', mdash: '--' }).to_html
       heading, html = html.split("</h1>\n", 2)
       return [nil, nil, nil] if html.nil?
 
@@ -256,7 +258,7 @@ module Ronn
     # Convert the document to HTML and return the result as a string.
     # The returned string is a complete HTML document.
     def to_html
-      layout = ENV['RONN_LAYOUT']
+      layout = ENV.fetch('RONN_LAYOUT', nil)
       layout_path = nil
       if layout
         layout_path = File.expand_path(layout)
@@ -313,7 +315,13 @@ module Ronn
     end
 
     def input_html
-      @input_html ||= strip_heading(Kramdown::Document.new(markdown, auto_ids: false, smart_quotes: ['apos', 'apos', 'quot', 'quot'], typographic_symbols: { hellip: '...', ndash: '--', mdash: '--' }).to_html)
+      @input_html ||= strip_heading(Kramdown::Document.new(markdown,
+        auto_ids: false,
+        input: 'GFM',
+        hard_wrap: 'false',
+        syntax_highlighter_opts: 'line_numbers: false',
+        smart_quotes: ['apos', 'apos', 'quot', 'quot'],
+        typographic_symbols: { hellip: '...', ndash: '--', mdash: '--' }).to_html)
     end
 
     def strip_heading(html)
@@ -368,7 +376,7 @@ module Ronn
 
     # Convert <WORD> to <var>WORD</var> but only if WORD isn't an HTML tag.
     def markdown_filter_angle_quotes(markdown)
-      markdown.gsub(/<([^:.\/]+?)>/) do |match|
+      markdown.gsub(/(?<!\\)<([^:.\/]+?)>/) do |match|
         contents = $1
         tag, attrs = contents.split(' ', 2)
         if attrs =~ /\/=/ || html_element?(tag.sub(/^\//, '')) ||
@@ -430,7 +438,7 @@ module Ronn
           "<h1>#{title}</h1>"
         elsif name
           "<h2>NAME</h2>\n" \
-            "<p class='man-name'>\n  <code>#{name}</code>" +
+          "<p class='man-name'>\n  <code>#{name}</code>" +
             (tagline ? " - <span class='man-whatis'>#{tagline}</span>\n" : "\n") +
             "</p>\n"
         end
